Sequences
=========

A sequence is a finite or infinite lazily evaluated list.

.. autofunction:: sympy.series.sequences::sequence

Sequences Base
---------------

.. autoclass:: sympy.series.sequences::SeqBase
   :members:

Elementary Sequences
--------------------

.. autoclass:: sympy.series.sequences::SeqFormula
   :members:

.. autoclass:: sympy.series.sequences::SeqPer
   :members:

Singleton Sequences
--------------------

.. autoclass:: sympy.series.sequences::EmptySequence
   :members:

Compound Sequences
--------------------

.. autoclass:: sympy.series.sequences::SeqAdd
   :members:

.. autoclass:: sympy.series.sequences::SeqMul
   :members:


Recursive Sequences
--------------------

.. autoclass:: sympy.series.sequences::RecursiveSeq
   :members:
